@@ -1,5 +1,5 @@
 import temgymbasic.geometry as geom
-from gui import *
+from temgymbasic.gui import *
 import pyqtgraph.opengl as gl
 import numpy as np
 from PyQt5.QtGui import QFont
